@@ -69,7 +69,7 @@ if config.CONFIG:
             catalog_ref = (
                 str(section.catalog)
                 if isinstance(section.catalog, HttpUrl)
-                else section.catalog.dict()
+                else section.catalog.dict()  # type: ignore
             )
             schema_catalog_registry.add_ref(name, catalog_ref)
     log.info("...done")
