@@ -6,7 +6,7 @@ import logging
 from collections import Counter
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Dict, Iterable, List
+from typing import Any, Dict, Iterable, List, Set
 from urllib.parse import urlencode, urljoin
 
 import frictionless
@@ -27,15 +27,23 @@ from validata_core.helpers import (
 
 from . import app, config, fetch_schema, pdf_service, schema_catalog_registry
 from .model import Section
-from .ui_util import flash_error, flash_warning
+from .ui_util import ThreadUpdater, flash_error, flash_warning
 from .validata_util import strip_accents
 
 log = logging.getLogger(__name__)
 
+schema_catalog_updater: Dict[str, ThreadUpdater] = {}
+
 
 def get_schema_catalog(section_name):
     """Return a schema catalog associated to a section_name."""
-    return schema_catalog_registry.build_schema_catalog(section_name)
+    global schema_catalog_updater
+
+    if section_name not in schema_catalog_updater:
+        schema_catalog_updater[section_name] = ThreadUpdater(
+            lambda: schema_catalog_registry.build_schema_catalog(section_name)
+        )
+    return schema_catalog_updater[section_name].value
 
 
 class SchemaInstance:
@@ -43,6 +51,7 @@ class SchemaInstance:
 
     def __init__(self, parameter_dict):
         """Initialize schema instance and tableschema catalog."""
+
         self.section_name = None
         self.section_title = None
         self.name = None
@@ -351,7 +360,7 @@ def get_badge_url_and_message(badge):
     return (badge_url, msg)
 
 
-def iter_task_errors(report: dict, code_set: set[str] = None) -> Iterable[dict]:
+def iter_task_errors(report: dict, code_set: Set[str] = None) -> Iterable[dict]:
     """Iterate on errors that prevent optimal validation."""
     if report["tasks"]:
         yield from (
@@ -426,7 +435,7 @@ def validate(schema_instance: SchemaInstance, validata_resource: ValidataResourc
             compute_validation_form_url(schema_instance.request_parameters())
         )
 
-    task_errors = list(iter_task_errors(validata_core_report))
+    task_errors = list(iter_task_errors(validata_core_report, {"task-error"}))
     if task_errors:
         err_msg = task_errors[0]["note"]
         log.error(err_msg)
@@ -556,67 +565,70 @@ def retrieve_schema_catalog(section: Section):
 # Routes
 
 
+def iter_sections():
+    """Yield sections of the home page, filled with schema metadata."""
+    # Iterate on all sections
+    for section in config.CONFIG.homepage.sections:
+
+        # section with only links to external validators
+        if section.links:
+            yield section
+            continue
+
+        # section with catalog
+        if section.catalog is None:
+            # skip section
+            continue
+
+        # retrieving schema catatalog
+        schema_catalog, catalog_error = retrieve_schema_catalog(section)
+        if schema_catalog is None:
+            yield catalog_error
+            continue
+
+        # Working on catalog
+        schema_info_list = []
+        for schema_reference in schema_catalog.references:
+            # retain tableschema only
+            if schema_reference.get_schema_type() != "tableschema":
+                continue
+
+            # Loads default table schema for each schema reference
+            schema_info = {"name": schema_reference.name}
+            try:
+                table_schema = fetch_schema(schema_reference.get_schema_url())
+            except json.JSONDecodeError:
+                schema_info["err"] = True
+                schema_info["title"] = (
+                    f"le format du schéma « {schema_info['name']} » "
+                    "n'est pas reconnu"
+                )
+            except Exception:
+                schema_info["err"] = True
+                schema_info["title"] = (
+                    f"le schéma « {schema_info['name']} » " "n'est pas disponible"
+                )
+            else:
+                schema_info["title"] = table_schema.get("title") or schema_info["name"]
+            schema_info_list.append(schema_info)
+        schema_info_list = sorted(
+            schema_info_list, key=lambda sc: strip_accents(sc["title"].lower())
+        )
+
+        yield {
+            **{k: v for k, v in section.dict().items() if k != "catalog"},
+            "catalog": schema_info_list,
+        }
+
+
+section_updater = ThreadUpdater(lambda: list(iter_sections()))
+
+
 @app.route("/")
 def home():
     """Home page."""
 
-    def iter_sections():
-        """Yield sections of the home page, filled with schema metadata."""
-        # Iterate on all sections
-        for section in config.CONFIG.homepage.sections:
-
-            # section with only links to external validators
-            if section.links:
-                yield section
-                continue
-
-            # section with catalog
-            if section.catalog is None:
-                # skip section
-                continue
-
-            # retrieving schema catatalog
-            schema_catalog, catalog_error = retrieve_schema_catalog(section)
-            if schema_catalog is None:
-                yield catalog_error
-                continue
-
-            # Working on catalog
-            schema_info_list = []
-            for schema_reference in schema_catalog.references:
-                # retain tableschema only
-                if schema_reference.get_schema_type() != "tableschema":
-                    continue
-                # Loads default table schema for each schema reference
-                schema_info = {"name": schema_reference.name}
-                try:
-                    table_schema = fetch_schema(schema_reference.get_schema_url())
-                except json.JSONDecodeError:
-                    schema_info["err"] = True
-                    schema_info["title"] = (
-                        f"le format du schéma « {schema_info['name']} » "
-                        "n'est pas reconnu"
-                    )
-                except Exception:
-                    schema_info["err"] = True
-                    schema_info["title"] = (
-                        f"le schéma « {schema_info['name']} » " "n'est pas disponible"
-                    )
-                else:
-                    schema_info["title"] = (
-                        table_schema.get("title") or schema_info["name"]
-                    )
-                schema_info_list.append(schema_info)
-            schema_info_list = sorted(
-                schema_info_list, key=lambda sc: strip_accents(sc["title"].lower())
-            )
-
-            yield {
-                **{k: v for k, v in section.dict().items() if k != "catalog"},
-                "catalog": schema_info_list,
-            }
-
-    return render_template("home.html", config=config, sections=list(iter_sections()))
+    return render_template("home.html", config=config, sections=section_updater.value)
 
 
 @app.route("/pdf")
@@ -644,7 +656,6 @@ def pdf_report():
         **schema_instance.request_parameters(),
     }
     validation_url = "{}?{}".format(base_url, urlencode(parameter_dict))
-    log.info("Validation URL = %s", validation_url)
 
     # Ask for PDF report generation
     try:
